MS Excel Spreadsheet converter Web Gateway

# An Excel Sheet converter Web Gateway

This is a web gateway converter for Excel Spreadsheet documents to html. This tool will convert any Microsoft Excel spreadsheet (XLS) file you send it, and then display the results in HTML format for you to read with your web browser.

To use this tool, press the Browse button below, and select the MS Excel XLS document you want to convert. Then Press the Upload File button to send it here for conversion.

File: |